<?php
/**
 * $Horde: igal/data.php,v 1.19 2003/01/09 01:06:39 jan Exp $
 *
 * Copyright 2001-2003 Jan Schneider <jan@horde.org>
 *
 * See the enclosed file COPYING for license information (GPL).  If you
 * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
 */

function _cleanup()
{
    global $import_step;
    $import_step = 1;
    return HORDE_IMPORT_FILE;
}

define('IGAL_BASE', dirname(__FILE__));
require_once IGAL_BASE . '/lib/base.php';
require_once HORDE_BASE . '/lib/Data.php';

if (!$conf['menu']['import_export']) {
    header('Location: ' . Horde::applicationUrl('index.php', true));
    exit;
}

/* Allow preferred theme to override settings. */
Horde::getThemeConfig(IGAL_BASE);

/* Importable file types. */
$file_types = array('csv' => _("CSV"));

/* Templates for the different import steps. */
$templates = array(
    HORDE_IMPORT_FILE      => array(IGAL_TEMPLATES . '/data/import.inc', IGAL_TEMPLATES . '/data/export.inc'),
    HORDE_IMPORT_CSVINFO   => array($registry->getParam('templates', 'horde') . '/data/csvinfo.inc'),
    HORDE_IMPORT_MAPFIELDS => array($registry->getParam('templates', 'horde') . '/data/csvmap.inc'),
    HORDE_IMPORT_DATETIME  => array($registry->getParam('templates', 'horde') . '/data/datemap.inc')
);

/* Field/clear name mapping. */
$app_fields = array('name'      => _("Name"),
                    'desc'      => _("Description"),
                    'category'  => _("Category"),
                    'due'       => _("Due By"),
                    'priority'  => _("Priority"),
                    'completed' => _("Completion Status"),
                    'flags'     => _("Flags"));

/* Date/time fields. */
$time_fields = array('due' => 'datetime');

/* Initial values. */
$param = array('time_fields' => $time_fields,
               'file_types'  => $file_types);
$import_format = Horde::getFormData('import_format', '');
$import_step   = Horde::getFormData('import_step', 0) + 1;
$actionID      = Horde::getFormData('actionID');
$error         = false;

/* Loop through the action handlers. */
switch ($actionID) {

case HORDE_EXPORT:
    $exportID = Horde::getFormData('exportID');

    /* Create a Igal storage instance. */
    require_once IGAL_BASE . '/lib/Driver.php';
    $storage = &Igal_Driver::factory($conf['projects']['driver'], Auth::getAuth(),
                                    $conf['projects']['params']);
    $storage->retrieve();

    /* Get the full, sorted project list. */
    $projects = Igal::listProjects($prefs->getValue('sortby'), $prefs->getValue('sortdir'));

    switch ($exportID) {
    case EXPORT_CSV:
        if (count($projects) == 0) {
            $notification->push(_("There were no projects to export."), 'horde.message');
            $error = true;
        } else {
            $data = array();
            foreach ($projects as $project) {
                unset($project['project_id']);
                $project['desc'] = str_replace(',', '', $project['desc']);
                $data[] = $project;
            }
            $csv = &Data::singleton('csv');
            $csv->exportFile(_("projects.csv"), $data, true);
            exit;
        }
    }
    break;

case HORDE_IMPORT_FILE:
    $_SESSION['import_data']['target'] = Horde::getFormData('projectlist_target');
    break;

}

if (!$error) {
    $data = &Data::singleton($import_format);
    if (is_a($data, 'PEAR_Error')) {
        $notification->push(_("This file format is not supported."), 'horde.error');
        $next_step = HORDE_IMPORT_FILE;
    } else {
        $next_step = $data->nextStep($actionID, $param);
        if (is_a($next_step, 'PEAR_Error')) {
            $notification->push($next_step->getMessage(), 'horde.error');
            $next_step = $data->cleanup();
        }
    }
}

/* We have a final result set. */
if (is_array($next_step)) {
    /* Create a Igal storage instance. */
    require_once IGAL_BASE . '/lib/Driver.php';
    $storage = &Igal_Driver::factory($conf['projects']['driver'], $_SESSION['import_data']['target'],
                                    $conf['projects']['params']);
    $storage->retrieve();
    foreach ($next_step as $row) {
        foreach ($app_fields as $field => $null) {
            if (!array_key_exists($field, $row)) {
                $row[$field] = '';
            }
        }
        $project_id = $storage->addProject($row['name'], $row['desc'], $row['due'],
                                     $row['priority'], $row['completed'],
                                     $row['category']);
        if (!empty($row['flags'])) {
            $storage->setFlag($project_id, $row['flags'], true);
        }
    }
    $success = $storage->store();
    if (is_a($success, 'PEAR_Error')) {
        $notification->push(sprintf(_("There was an error importing the data: %s"),
                                    $success->getMessage()), 'horde.error');
    } else {
        $notification->push(sprintf(_("%s file successfully imported"),
                                    $file_types[$_SESSION['import_data']['format']]), 'horde.success');
    }
    $next_step = $data->cleanup();
}

$title = _("Import/Export Projects");
$js_onLoad = null;
require IGAL_TEMPLATES . '/common-header.inc';
require IGAL_BASE . '/menu.php';

$notification->notify();

foreach ($templates[$next_step] as $template) {
    require $template;
}

require IGAL_TEMPLATES . '/common-footer.inc';
