<?php
/**
 * $Horde: igal/image.php,v 1.36 2003/02/06 18:32:21 chuck Exp $
 *
 * Copyright 2001-2003 Jon Parise <jon@horde.org>
 *
 * See the enclosed file COPYING for license information (GPL).  If you
 * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
 */

define('IGAL_BASE', dirname(__FILE__));
require_once IGAL_BASE . '/lib/base.php';
require_once HORDE_BASE . '/lib/Server.php';

/* Redirect to the image list if no action has been requested. */
$actionID = Horde::getFormData('actionID');
$project_id = Horde::getFormData('project');
if (is_null($actionID)) {
    header('Location: ' . Horde::applicationUrl('list.php', true));
    exit;
}

/* Run through the action handlers. */
switch ($actionID) {
case IGAL_ADD_IMAGE:
    /* Set up the image attributes. */
    $project_owner = Auth::getAuth();
    $image_id = null;
    $image_default = null;
    $image_filename = '';
    $image_desc = '';
    $image_category = 0;

    $title = _("Adding A New Image to Project");
    break;

case IGAL_MODIFY_IMAGE:
    $image_id = Horde::getFormData('image');
    $project_id = Horde::getFormData('project');
    $project_owner = Horde::getFormData('projectlist');
    $image = Igal::getImage($project_owner, $project_id,  $image_id);

    if ($image) {
        /* Set up the project attributes. */
        $image_desc = $image['desc'];
        $image_default = $image['project_default'];

        $title = _("Modifying: Image");
    } else {
        $title = _("Unknown project");
    }
    break;


case IGAL_SAVE_IMAGE:
    /* Get the form values. */
    $image_id = Horde::getFormData('image');
    $project_id = Horde::getFormData('project');
    $project_owner = Horde::getFormData('project_owner');
    $image_desc = Horde::getFormData('image_desc');

    if (Horde::getFormData('project_default') == 'on') {
        $image_default = 1; 
    } else {
        $image_default = 0;
    }

    if ($image_id == null) {
        if (!is_a(Server::wasFileUploaded('image_file'), 'PEAR_Error')) {
            $image_file = array('tmp' => $_FILES['image_file']['tmp_name'],
                                'name' => 'image_' . date("is") . '.jpg',
                                'type' => $_FILES['image_file']['type'],
                                'error' => $_FILES['image_file']['error'],
                                'dest' => IGAL_BASE . $conf['images']['params']['incoming_dest']  . '/project_' . $project_owner . '_' . $project_id);

            /* Move the Uploaded File to the Project Folder */
            if (is_a(Igal::moveImageFile($image_file['tmp'], $image_file['dest'] . '/tmp.jpg'), 'PEAR_Error')) {
                $notification->push(sprintf(_("Could not Move Image")), 'horde.error');
                /* Log the Problem at a DEBUG log level. */
                Horde::logMessage(sprintf('IGAL_SAVE_IMAGE: There was a problem moving the image'),
                                  __FILE__, __LINE__, LOG_DEBUG);
            }
            /* Resize the Image to the full size and thumbnail size image */
            if (is_a(Igal::resizeImage($image_file['dest'] . '/tmp.jpg', 300, 100, $image_file['dest'] . '/' . $image_file['name']), 'PEAR_Error')) {
                $notification->push(sprintf(_("There was a problem Resizing the image")), 'horde.error');
                /* Log the Problem at a DEBUG log level. */
                Horde::logMessage(sprintf('IGAL_SAVE_IMAGE: There was a problem Resizing the image'),
                                  __FILE__, __LINE__, LOG_DEBUG);
            }
        } else {
            $notification->push(sprintf(_("There was a problem uploading the image")), 'horde.error');
            /* Log the Problem at a DEBUG log level. */
            Horde::logMessage(sprintf('IGAL_SAVE_IMAGE: There was a problem uploading the image: ErrorNo: %d', $_FILES['image_file']['error']),
                              __FILE__, __LINE__, LOG_DEBUG);
        }
    }
    $share = $GLOBALS['igal_shares']->getShare($project_owner);

    if (is_a($share, 'PEAR_Error') || !$share->hasPermission(Auth::getAuth(), _PERMS_EDIT)) {
        $notification->push(sprintf(_("Access denied saving image to %s."), $share->getShareName()), 'horde.error');
    } else {

        if ($image_id != null) {
            $storage = &Igal_Driver::singleton($conf['images']['driver'], $project_owner,
                                               $conf['images']['params']);
            $storage->retrieveImage($project_id);

            $storage->modifyImage($image_id, 'project_default', $image_default);
            $storage->modifyImage($image_id, 'desc', $image_desc);
        } else {
            $storage = &Igal_Driver::singleton($conf['images']['driver'], $project_owner,
                                               $conf['images']['params']);
            $storage->retrieveImage($project_id);

            $image_id = $storage->addImage($project_id, $image_default, $image_desc, $image_file['name']);
        }

        /* Store the changes. */
        if (!is_a($storage->storeImage(), 'PEAR_Error')) {
            $notification->push(_("The image was saved."), 'horde.success');
        } else {
            $notification->push(_("There was a problem saving the image."), 'horde.error');
        }
    }

    /* Return to the image list. */
    $imageurl = Horde::addParameter('view.php', 'project=' . $project_id);
    $imageurl = Horde::addParameter($imageurl, 'projectlist=' . $project_owner);
    $imageurl = Horde::addParameter($imageurl, 'image=' . $image_id);
    $imageurl = Horde::addParameter($imageurl, 'actionID=' . IGAL_VIEW_IMAGE);
    header('Location: ' . Horde::applicationUrl($imageurl, true));
    exit;
    break;

case IGAL_DELETE_IMAGE:
    /* Delete the image if we're provided with a valid image ID. */
    $image_id = Horde::getFormData('image');
    $project_id = Horde::getFormData('project');
    $project_owner = Horde::getFormData('projectlist');
    if (isset($image_id)) {
        $share = $GLOBALS['igal_shares']->getShare($project_owner);
        if (is_a($share, 'PEAR_Error') || !$share->hasPermission(Auth::getAuth(), _PERMS_DELETE)) {
            $image = Igal::getImage($project_owner, $project_id, $image_id);
            $notification->push(sprintf(_("Access denied deleting image %s."), $image['name']), 'horde.error');
        } else {
            $storage = &Igal_Driver::singleton($conf['images']['driver'], $project_owner,
                                              $conf['images']['params']);
            $storage->retrieveImage($project_id);

            $storage->deleteImage($image_id);
            if (!is_a($storage->storeImage(), 'PEAR_Error')) {
                $notification->push(_("Deleted 1 image."), 'horde.success');
            } else {
                $notification->push(_("There was a problem deleting images."), 'horde.error');
            }
        }
    }

    /* Return to the image list. */
    /* Return to the image list. */
    $imageurl = Horde::addParameter('view.php', 'project=' . $project_id);
    $imageurl = Horde::addParameter($imageurl, 'projectlist=' . $project_owner);
    $imageurl = Horde::addParameter($imageurl, 'actionID=' . IGAL_VIEW_PROJECT);
    header('Location: ' . Horde::applicationUrl($imageurl, true));

    exit;
    break;

default:
    header('Location: ' . Horde::applicationUrl('list.php', true));
    exit;
}

$js_onLoad = null;
require IGAL_TEMPLATES . '/common-header.inc';
require IGAL_BASE . '/menu.php';
$notification->notify();
require IGAL_TEMPLATES . '/image/begin.inc';
require IGAL_TEMPLATES . '/image/image.inc';
require IGAL_TEMPLATES . '/image/end.inc';
require IGAL_TEMPLATES . '/common-footer.inc';

