<?php
/**
 * Igal base inclusion file.
 *
 * $Horde: igal/lib/base.php,v 1.46 2003/01/05 18:34:54 jan Exp $
 *
 * This file brings in all of the dependencies that every Igal
 * script will need and sets up objects that all scripts use.
 */

// Find the base file path of Horde
@define('HORDE_BASE', dirname(__FILE__) . '/../..');

// Find the base file path of Igal
@define('IGAL_BASE', dirname(__FILE__) . '/..');

// Registry
require_once HORDE_BASE . '/lib/Registry.php';
$registry = &Registry::singleton();
$registry->pushApp('igal');
$conf = &$GLOBALS['conf'];
@define('IGAL_TEMPLATES', $registry->getParam('templates'));

// Horde base libraries
require_once HORDE_BASE . '/lib/Horde.php';
require_once HORDE_BASE . '/lib/Auth.php';
require_once HORDE_BASE . '/lib/Text.php';
require_once HORDE_BASE . '/lib/Help.php';

// Don't allow access unless there is a Horde login or guests are
// allowed.
if (!Auth::getAuth() && !$registry->allowGuests()) {
    Horde::authenticationFailureRedirect();
}

// Igal base libraries
require_once IGAL_BASE . '/lib/Igal.php';
require_once IGAL_BASE . '/lib/Driver.php';

// Browser detection library
require_once HORDE_BASE . '/lib/Browser.php';
$browser = &new Browser();

// Notification sytem
require_once HORDE_BASE . '/lib/Notification.php';
$notification = &Notification::singleton();
$notification->attach('status');

// Set the timezone variable, if available.
NLS::setTimeZone();

// Make sure a session exists
if (!array_key_exists('igal', $_SESSION)) {
    $_SESSION['igal'] = array();
}

// Create a share instance.
require_once HORDE_BASE . '/lib/Share.php';
$GLOBALS['igal_shares'] = &Horde_Share::singleton($registry->getApp());

// Update the preference for what project lists to display. If the user doesn't
// have any selected project lists for view then fall back to some available
// list.
$GLOBALS['display_projectlists'] = unserialize($GLOBALS['prefs']->getValue('display_projectlists'));
if (($d_project = Horde::getFormData('display_projectlist')) !== null) {
    if (in_array($d_project, $GLOBALS['display_projectlists'])) {
        $key = array_search($d_project, $GLOBALS['display_projectlists']);
        unset($GLOBALS['display_projectlists'][$key]);
    } else {
        $GLOBALS['display_projectlists'][] = $d_project;
    }
}

// Make sure all project lists exist now, to save on checking later.
$_temp = $GLOBALS['display_projectlists'];
$_all = Igal::listProjectlists();
$GLOBALS['display_projectlists'] = array();
foreach ($_temp as $id) {
    if (isset($_all[$id])) {
        $GLOBALS['display_projectlists'][] = $id;
    }
}
$GLOBALS['prefs']->setValue('display_projectlists', serialize($GLOBALS['display_projectlists']));

// Make sure we have at least one project list to work with.
if (count($GLOBALS['display_projectlists']) == 0) {
    // Find a project list to fall back on.
    $lists = Igal::listProjectlists(true);
    if (count($lists) > 0) {
        if (array_key_exists(Auth::getAuth(), $lists)) {
            // User's personal project list.
            $GLOBALS['display_projectlists'] = array(Auth::getAuth());
        } else {
            // Some other project list they own.
            $GLOBALS['display_projectlists'] = array(array_pop(array_keys($lists)));
        }
    } elseif (Auth::getAuth()) {
        // Create a personal project list.
        $GLOBALS['display_projectlists'] = array(Auth::getAuth());

        // If this share doesn't exist then create it.
        if (!$GLOBALS['igal_shares']->exists(Auth::getAuth())) {
            $share = $GLOBALS['igal_shares']->newShare(Auth::getAuth());
            $share->setOwner(Auth::getAuth(), false);
            $share->setShareName(_("My Project List"), false);
            $GLOBALS['igal_shares']->addShare($share);
        }
    }
    $GLOBALS['prefs']->setValue('display_projectlists', serialize($GLOBALS['display_projectlists']));
}
