<?php
/**
 * $Horde: igal/list.php,v 1.50 2003/01/03 12:44:45 jan Exp $
 *
 * Copyright 2001-2003 Jon Parise <jon@horde.org>
 *
 * See the enclosed file COPYING for license information (GPL).  If you
 * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
 */

@define('IGAL_BASE', dirname(__FILE__));
require_once IGAL_BASE . '/lib/base.php';
require_once IGAL_BASE . '/config/html.php';

/* Allow preferred theme to override settings. */
Horde::getThemeConfig(IGAL_BASE);

/* Get the current action ID. */
$actionID = Horde::getFormData('actionID');

/* Sort out the sorting values and project filtering. */
if (($sortby = Horde::getFormData('sortby')) !== null) {
    $prefs->setValue('sortby', $sortby);
}
if (($sortdir = Horde::getFormData('sortdir')) !== null) {
    $prefs->setValue('sortdir', $sortdir);
}
if (($show_completed = Horde::getFormData('show_completed')) !== null) {
    $prefs->setValue('show_completed', $show_completed);
}

/* Get the full, sorted project list. */
$projects = igal::listProjects($prefs->getValue('sortby'),
                        $prefs->getValue('sortdir'));

/* Page variables. */
$i = 0;
$title = _("Projects");
$js_onLoad = null;

switch ($actionID) {
case IGAL_SEARCH_PROJECTS:
    /* If we're searching, only list those projects that match the
       search result. */
    /* Get the search parameters. */
    $pattern = Horde::getFormData('search_pattern');
    $search_name = (Horde::getFormData('search_name') == 'on');
    $search_desc = (Horde::getFormData('search_desc') == 'on');

    if (!empty($pattern) && ($search_name || $search_desc)) {
        $search_results = array();
        foreach ($projects as $project_id => $project) {
            if (($search_name && preg_match("/$pattern/i", $project['name'])) || 
                ($search_desc && preg_match("/$pattern/i", $project['desc']))) {
                $search_results[$project_id] = $project;
            }
        }

        /* Reassign $projects to the search result. */
        $projects = $search_results;
        $title = _("Search Results");
    }
    break;
}

$list = Horde::applicationUrl('list.php');
$all_link = Horde::link(Horde::addParameter($list, 'show_completed=1'), _("All projects"), 'menuitem') . _("All projects") . '</a>';
#$complete_link = Horde::link(Horde::addParameter($list, 'show_completed=2'), _("Complete projects"), 'menuitem') . _("Complete projects") . '</a>';
#$incomplete_link = Horde::link(Horde::addParameter($list, 'show_completed=0'), _("Incomplete projects"), 'menuitem') . _("Incomplete projects") . '</a>';
switch ($prefs->getValue('show_completed')) {
 case 1: // All projects
     $all_link = _("All projects");
     break;

 case 0: // Incomplete projects
     $incomplete_link = _("Incomplete projects");
     break;

 case 2: // Complete projects
     $complete_link = _("Complete projects");
     break;
}

require IGAL_TEMPLATES . '/common-header.inc';
require IGAL_BASE . '/menu.php';
$notification->notify();
require IGAL_TEMPLATES . '/list/javascript.inc';
require IGAL_TEMPLATES . '/list/header.inc';

if (count($projects) > 0) {
    require IGAL_TEMPLATES . '/list/project_headers.inc';

    foreach ($projects as $project_id => $project) {
        /*if (!empty($project['completed'])) {
            $style = 'closed';
        } else {
            $style = 'text' . $project['priority'];
        }*/
        $viewurl = Horde::addParameter('view.php', 'project=' . $project['project_id']);
        $viewurl = Horde::addParameter($viewurl, 'projectlist=' . $project['projectlist_id']);
        $viewurl = Horde::addParameter($viewurl, 'actionID=' . IGAL_VIEW_PROJECT);

        $projecturl = Horde::addParameter('project.php', 'project=' . $project['project_id']);
        $projecturl = Horde::addParameter($projecturl, 'projectlist=' . $project['projectlist_id']);
        $share = $GLOBALS['igal_shares']->getShare($project['projectlist_id']);

        $owner = $project['projectlist_id'];
        if (!is_a($share, 'PEAR_Error') && $owner != $share->getOwner()) {
            $owner = $share->getShareName();
        }

        require IGAL_TEMPLATES . '/list/project_summaries.inc';
    }

    require IGAL_TEMPLATES . '/list/project_footers.inc';
} else {
    require IGAL_TEMPLATES . '/list/empty.inc';
}

require IGAL_TEMPLATES . '/list/footer.inc';
require IGAL_TEMPLATES . '/common-footer.inc';
