<?php
/**
 * $Horde: igal/project.php,v 1.36 2003/02/06 18:32:21 chuck Exp $
 *
 * Copyright 2001-2003 Jon Parise <jon@horde.org>
 *
 * See the enclosed file COPYING for license information (GPL).  If you
 * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
 */

define('IGAL_BASE', dirname(__FILE__));
require_once IGAL_BASE . '/lib/base.php';

/* Redirect to the project list if no action has been requested. */
$actionID = Horde::getFormData('actionID');
if (is_null($actionID)) {
    header('Location: ' . Horde::applicationUrl('list.php', true));
    exit;
}

/* Run through the action handlers. */
switch ($actionID) {
case IGAL_ADD_PROJECT:
    /* Set up the project attributes. */
    $projectlist_id = $prefs->getValue('default_projectlist');
    $project_id = null;
    $project_name = '';
    $project_desc = '';
    $project_category = 0;

    /* Set the initial due date to one week from now. */
    #$initial_date = time() + 604800;
    #$javascript = 'onchange="document.project.due_type[1].checked = true;"';
    #$day_widget = Igal::buildDayWidget('due_day', $initial_date, $javascript);
    #$month_widget = Igal::buildMonthWidget('due_month', $initial_date, $javascript);
    #$year_widget = Igal::buildYearWidget('due_year', 3, $initial_date, $javascript);
    #$hour_widget = Igal::buildHourWidget('due_hour', $initial_date, $javascript);
    #$minute_widget = Igal::buildMinuteWidget('due_minute', 15, null, $javascript);

    /* Set up the radio buttons. */
    #$none_checked = ($project_due == 0) ? 'checked="checked" ' : '';
    #$specified_checked = ($project_due != 0) ? 'checked="checked" ' : '';

    $title = _("Adding A New Project");
    break;

case IGAL_MODIFY_PROJECT:
    $project_id = Horde::getFormData('project');
    $projectlist_id = Horde::getFormData('projectlist');
    $project = Igal::getProject($projectlist_id, $project_id);

    if ($project) {
        /* Set up the project attributes. */
        $project_name = $project['name'];
        $project_desc = $project['desc'];
        $project_category = $project['category'];

        $title = _("Modifying:") . ' ' . $project_name;
    } else {
        $title = _("Unknown project");
    }
    break;

case IGAL_SAVE_PROJECT:
    /* Get the form values. */
    $project_id = Horde::getFormData('project');
    $projectlist_original = Horde::getFormData('projectlist_original');
    $projectlist_target = Horde::getFormData('projectlist_target');

    $share = $GLOBALS['igal_shares']->getShare($projectlist_target);
    if (is_a($share, 'PEAR_Error') || !$share->hasPermission(Auth::getAuth(), _PERMS_EDIT)) {
        $notification->push(sprintf(_("Access denied saving project to %s."), $share->getShareName()), 'horde.error');
    } else {
        $project_name = Horde::getFormData('project_name');
        $project_desc = Horde::getFormData('project_desc');
        $project_category = Horde::getFormData('project_category');

        if ($project_category == '*new*') {
            $new_category = Horde::getFormData('new_category');
            $project_category = Igal::addCategory($new_category);
            if ($project_category == 0) {
                $notification->push(sprintf(_('Unable to create new category: %s'), $new_category), 'horde.warning');
            }
        }

        if ($project_id !== null && !empty($projectlist_original)) {
            if ($projectlist_original != $projectlist_target) {
                /* Saving to a different project list */
                $share = $GLOBALS['igal_shares']->getShare($projectlist_original);
                if (!is_a($share, 'PEAR_Error') && $share->hasPermission(Auth::getAuth(), _PERMS_DELETE)) {
                    $storage = &Igal_Driver::singleton($conf['projects']['driver'], $projectlist_original,
                                                      $conf['projects']['params']);
                    $storage->retrieveProject();

                    $storage->deleteProject($project_id);

                    if (is_a($storage->storeProject(), 'PEAR_Error')) {
                        $notification->push(sprintf(_("There was a problem removing the project from %s."), $share->getShareName()), 'horde.error');
                    }
                } else {
                    $notification->push(sprintf(_("Access denied removing project from %s."), $share->getShareName()), 'horde.error');
                }

                $storage = &Igal_Driver::singleton($conf['projects']['driver'], $projectlist_target,
                                                  $conf['projects']['params']);
                $storage->retrieveProject();

                $project_id = $storage->addProject($project_name, $project_desc, $project_category);
            } else {
                /* Saving to the same project list. */
                $storage = &Igal_Driver::singleton($conf['projects']['driver'], $projectlist_target,
                                                  $conf['projects']['params']);
                $storage->retrieveProject();

                $storage->modifyProject($project_id, 'name', $project_name);
                $storage->modifyProject($project_id, 'desc', $project_desc);
                $storage->modifyProject($project_id, 'category', $project_category);
            }
        } else {
            $storage = &Igal_Driver::singleton($conf['projects']['driver'], $projectlist_target,
                                              $conf['projects']['params']);
            $storage->retrieveProject();

            $project_id = $storage->addProject($project_name, $project_desc, $project_category);
        }

        /* Store the changes. */
        $ret = $storage->storeProject();
        
        if (!is_a($ret, 'PEAR_Error')) {
            $notification->push(_("The project was saved."), 'horde.success');
        } else {
            $notification->push(_("There was a problem saving the project."), 'horde.error');
        }
    }

    /* Return to the project list. */
    $projecturl = Horde::addParameter('view.php', 'project=' . $project_id);
    $projecturl = Horde::addParameter($projecturl, 'projectlist=' . $projectlist_target);
    $projecturl = Horde::addParameter($projecturl, 'actionID=' . IGAL_VIEW_PROJECT);
    header('Location: ' . Horde::applicationUrl($projecturl, true));
    exit;
    break;

case IGAL_DELETE_PROJECT:
    /* Delete the project if we're provided with a valid project ID. */
    $project_id = Horde::getFormData('project');
    $projectlist_id = Horde::getFormData('projectlist');
    if (isset($project_id)) {
        $share = $GLOBALS['igal_shares']->getShare($projectlist_id);
        if (is_a($share, 'PEAR_Error') || !$share->hasPermission(Auth::getAuth(), _PERMS_DELETE)) {
            $project = Igal::getProject($projectlist_id, $project_id);
            $notification->push(sprintf(_("Access denied deleting project %s."), $project['name']), 'horde.error');
        } else {
            $storage = &Igal_Driver::singleton($conf['images']['driver'], $projectlist_id,
                                              $conf['images']['params']);
                                                                                                                                                    
            $storage->retrieveImage($project_id);
                                                                                                                                                    
            $storage->deleteAll('image');
                                                                                                                                                    
            if (!is_a($storage->StoreImage(), 'Pear_Error')) {
                $notification->push(_("Deleted All project Images."), 'horde.success');
            } else {
                $notification->push(_("There was a problem deleting project images."), 'horde.error');
            }

            $storage = &Igal_Driver::singleton($conf['projects']['driver'], $projectlist_id,
                                              $conf['projects']['params']);
            $storage->retrieveProject();

            $storage->deleteProject($project_id);

            if (!is_a($storage->storeProject(), 'PEAR_Error')) {
                $notification->push(_("Deleted 1 project."), 'horde.success');
            } else {
                $notification->push(_("There was a problem deleting projects."), 'horde.error');
            }
        }
    }

    /* Return to the project list. */
    header('Location: ' . Horde::applicationUrl('list.php', true));
    exit;
    break;

case IGAL_PREVIEW_PROJECT:
/*
    // Complete the project if we're provided with a valid project ID. 
    $project_id = Horde::getFormData('project');
    $projectlist_id = Horde::getFormData('projectlist');
    if (isset($project_id)) {
        $share = $GLOBALS['igal_shares']->getShare($projectlist_id);
        if (is_a($share, 'PEAR_Error') || !$share->hasPermission(Auth::getAuth(), _PERMS_EDIT)) {
            $project = Igal::getProject($projectlist_id, $project_id);
            $notification->push(sprintf(_("Access denied completing project %s."), $project['name']), 'horde.error');
        } else {
            $storage = &Igal_Driver::singleton($conf['projects']['driver'], $projectlist_id,
                                              $conf['projects']['params']);
            $storage->retrieveProject();

            $storage->modifyProject($project_id, 'completed', 1);
            if (!is_a($storage->storeProject(), 'PEAR_Error')) {
                $notification->push(_("Marked project as completed."), 'horde.success');
            } else {
                $notification->push(_("There was a problem setting project completion status."), 'horde.error');
            }
        }
    }

    /* Return to the project list. */
    header('Location: ' . Horde::applicationUrl('list.php', true));
    exit;
    break;

default:
    header('Location: ' . Horde::applicationUrl('list.php', true));
    exit;
}

$js_onLoad = null;
require IGAL_TEMPLATES . '/common-header.inc';
require IGAL_BASE . '/menu.php';
$notification->notify();
require IGAL_TEMPLATES . '/project/begin.inc';
require IGAL_TEMPLATES . '/project/project.inc';
require IGAL_TEMPLATES . '/project/end.inc';
require IGAL_TEMPLATES . '/common-footer.inc';
