<?php
/**
 * $Horde: igal/projectlists.php,v 1.10 2003/01/03 02:18:49 jan Exp $
 *
 * Copyright 2002-2003 Joel Vandal <jvandal@infoteck.qc.ca>
 * Copyright 2002-2003 Mike Cochrane <mike@graftonhall.co.nz>
 *
 * See the enclosed file COPYING for license information (GPL).  If you
 * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
 */

define('SHARE_EDIT',   1);
define('SHARE_SAVE',   2);
define('SHARE_DELETE', 3);
define('SHARE_ACCESS', 4);
define('IGAL_BASE', dirname(__FILE__));
require_once IGAL_BASE . '/lib/base.php';

// Exit if this isn't an authenticated user.
if (!Auth::getAuth()) {
    require IGAL_BASE . '/list.php';
    exit;
}

$to_edit = null;
$onlynew = 0;
$actionID = Horde::getFormData('actionID');

// Handle clients without javascript.
if (is_null($actionID)) {
    if (isset($_POST['edit'])) {
        $actionID = SHARE_EDIT;
    } elseif (isset($_POST['save'])) {
        $actionID = SHARE_SAVE;
    } elseif (isset($_POST['delete'])) {
        $actionID = SHARE_DELETE;
    } elseif (isset($_POST['accesslist'])) {
        $actionID = SHARE_ACCESS;
    } elseif (isset($_POST['back'])) {
        header('Location: ' . Horde::applicationUrl('prefs.php', true));
        exit;
    }
}

/* Run through the action handlers */
switch ($actionID) {
 case SHARE_EDIT:
    $to_edit = Horde::getFormData('share');
    break;

 case SHARE_SAVE:
    $to_edit = Horde::getFormData('edit_share');
    $id = Horde::getFormData('id');
    if (empty($id)) {
        $notification->push(_("The project list name is empty."), 'horde.error');
        break;
    }

    $projectlist = '';
    if (!isset($to_edit) || $to_edit == '') {
        /* Create New Share */
        $projectlist = $GLOBALS['igal_shares']->newShare(md5(microtime()));
        $projectlist->setOwner(Auth::getAuth(), false);
        $projectlist->setShareName($id, false);
        $projectlist->setType(Horde::getFormData('type', 0), false);
        $projectlist->setDescription(Horde::getFormData('description', ''), false);
        $result = $GLOBALS['igal_shares']->addShare($projectlist);

        if (is_a($result, 'PEAR_Error')) {
            $notification->push(sprintf(_("The project list \"%s\" couldn't be created: %s"), $id, $result->getMessage()), 'horde.error');
        } else {
            $notification->push(sprintf(_("The project list \"%s\" has been created."), $id), 'horde.success');
        }
    } else {
        $projectlist = &$GLOBALS['igal_shares']->getShare($to_edit);
        $projectlist->setShareName($id, false);
        $projectlist->setType(Horde::getFormData('type', 0), false);
        $projectlist->setDescription(Horde::getFormData('description', ''));

        $notification->push(sprintf(_("The project list \"%s\" has been saved."), $id), 'horde.success');
    }

    unset($to_edit);
    break;

 case SHARE_DELETE:
    $to_delete = Horde::getFormData('edit_share');
    $id = Horde::getFormData('id');

    if (isset($to_delete)) {
        $share = $GLOBALS['igal_shares']->getShare($to_delete);

        // Delete the projectlist.
        require_once IGAL_BASE . '/lib/Driver.php';
        $storage = &Igal_Driver::factory($conf['projects']['driver'], $to_delete,
                                        $conf['projects']['params']);
        $storage->retrieve();
        $storage->deleteAll();

        if (PEAR::isError($storage->store())) {
            $notification->push(sprintf(_("Unable to delete \"%s\": %s"), $share->getShareName(), $res->getMessage()), 'horde.error');
        } else {
            // Remove share and all groups/permissions.
            $GLOBALS['igal_shares']->removeShare($share);
            $notification->push(sprintf(_("The project list \"%s\" has been deleted."), $share->getShareName()), 'horde.success');
        }
    } else {
        $notification->push(_("You must select a project list to be deleted."), 'horde.warning');
    }

    // Make sure we still on at least one project list
    if (count(Igal::listProjectlists(true)) == 0) {
        /* If this share doesn't exist then create it */
        if (!$GLOBALS['igal_shares']->exists(Auth::getAuth())) {
            $share = $GLOBALS['igal_shares']->newShare(Auth::getAuth());
            $share->setOwner(Auth::getAuth());
            $share->setShareName(_("My Project List"));
            $GLOBALS['igal_shares']->addShare($share);
        }
    }
    break;

 case SHARE_ACCESS:
    $edit_share = Horde::getFormData('edit_share');
    $id = Horde::getFormData('id');
    $type = Horde::getFormData('type');

    if ($type == 1) {
        header('Location: ' . Horde::applicationUrl('projectlists/members.php?edit_share=' . $edit_share, true));
    }
    break;
}

$title = _("Project Lists");
$js_onLoad = null;

/* Personal Project Lists */
$personal_projectlists = Igal::listProjectlists(true);

require IGAL_TEMPLATES . '/common-header.inc';
require_once $registry->getParam('templates', 'horde') . '/javascript/open_share_edit_win.js';
require IGAL_BASE . '/menu.php';
$notification->notify();
require IGAL_TEMPLATES . '/projectlists/javascript.inc';
require IGAL_TEMPLATES . '/projectlists/manage.inc';
require IGAL_TEMPLATES . '/common-footer.inc';
